Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3372)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_container.h

Issue 10949005: Fix toolbar keyboard accessibility on Views (alternative impl). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix test on linux_chromeos Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/views/location_bar/location_bar_container.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/location_bar/location_bar_container.h
diff --git a/chrome/browser/ui/views/location_bar/location_bar_container.h b/chrome/browser/ui/views/location_bar/location_bar_container.h
index 499f8abe580924e11f429fbea058ff02fe3b96c2..3497fc0ab17a3b3f36889aca291041996ab574de 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_container.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_container.h
@@ -13,6 +13,8 @@
class LocationBarView;
namespace views {
+class AccessiblePaneView;
+class FocusTraversable;
class NativeViewHost;
}
@@ -25,8 +27,11 @@ class NativeViewHost;
class LocationBarContainer : public views::View,
public views::BoundsAnimatorObserver {
public:
- // Creates a new LocationBarContainer as a child of |parent|.
- LocationBarContainer(views::View* parent, bool instant_extended_api_enabled);
+ // Creates a new LocationBarContainer as a child of |parent|,
+ // with |accessible_pane_view| as the owning view for focus searching.
+ LocationBarContainer(views::View* parent,
+ views::AccessiblePaneView* accessible_pane_view,
+ bool instant_extended_api_enabled);
virtual ~LocationBarContainer();
// Sets whether the LocationBarContainer is in the toolbar.
@@ -56,6 +61,7 @@ class LocationBarContainer : public views::View,
virtual bool SkipDefaultKeyEventProcessing(
const ui::KeyEvent& event) OVERRIDE;
virtual void GetAccessibleState(ui::AccessibleViewState* state) OVERRIDE;
+ virtual views::FocusTraversable* GetPaneFocusTraversable() OVERRIDE;
// views::BoundsAnimatorObserver overrides:
virtual void OnBoundsAnimatorProgressed(
@@ -87,6 +93,8 @@ class LocationBarContainer : public views::View,
bool in_toolbar_;
+ views::AccessiblePaneView* accessible_pane_view_;
+
bool instant_extended_api_enabled_;
DISALLOW_COPY_AND_ASSIGN(LocationBarContainer);
« no previous file with comments | « no previous file | chrome/browser/ui/views/location_bar/location_bar_container.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698